@@ -2,7 +2,7 @@ import csv
 import itertools
 from pathlib import Path
 
-from PyQt5.QtWidgets import QFrame
+from qtpy.QtWidgets import QFrame
 from qtpy.QtWidgets import QVBoxLayout, QDialog
 
 from napari_allencell_annotator.controller.images_controller import ImagesController
